@@ -33,7 +33,7 @@ import numpy as np
 import pandas as pd
 from equilibrator_cache.zenodo import get_cached_filepath
 
-from . import ZENODO_DOI_PARAMETERS
+from . import DEFAULT_CC_PARAMS_SETTINGS, ZenodoSettings
 
 
 logger = logging.getLogger(__name__)
@@ -53,14 +53,15 @@ class CCModelParameters(namedtuple("CCModelParameters", PARAMETER_NAMES)):
 
     @staticmethod
     def from_zenodo(
-        zenodo_doi: str = ZENODO_DOI_PARAMETERS,
+        settings: ZenodoSettings = DEFAULT_CC_PARAMS_SETTINGS,
     ) -> "CCModelParameters":
         """Get the CC parameters from Zenodo.
 
         Parameters
         ----------
-        zenodo_doi : str
-            The DOI for the Zenodo entry
+        params : dict
+            A dictionary with the relevant Zenodo parameters:
+            zenodo_doi, zenodo_fname, and zenodo_md5 (optional)
 
         Returns
         -------
@@ -68,9 +69,7 @@ class CCModelParameters(namedtuple("CCModelParameters", PARAMETER_NAMES)):
             a collection of Component Contribution parameters.
 
         """
-        params_file = get_cached_filepath(
-            zenodo_doi=zenodo_doi, zenodo_fname="cc_params.npz"
-        )
+        params_file = get_cached_filepath(settings)
         return CCModelParameters.from_npz(params_file)
 
     def to_npz(self, file: Union[str, BinaryIO]) -> None:
