@@ -64,7 +64,12 @@ from equilibrator_cache.reaction import (
 )
 from equilibrator_cache.zenodo import get_cached_filepath
 
-from . import ZENODO_DOI_GROUPS, ZENODO_DOI_TRAINING_DATA
+from . import (
+    GROUP_DEFINITIONS_SETTINGS,
+    TRAINING_DATA_FORMATION_SETTINGS,
+    TRAINING_DATA_REDOX_SETTINGS,
+    TRAINING_DATA_TECR_SETTINGS,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -102,9 +107,7 @@ class TrainingData(object):
         self.S = None  # a DataFrame containing the stoichiometric matrix
 
         # read the group summary table from Zenodo
-        group_file = get_cached_filepath(
-            zenodo_doi=ZENODO_DOI_GROUPS, zenodo_fname="group_summary.csv"
-        )
+        group_file = get_cached_filepath(GROUP_DEFINITIONS_SETTINGS)
         self.group_summary = pd.read_csv(group_file, index_col=0)
 
         logger.info("Gathering reaction data")
@@ -385,24 +388,17 @@ class FullTrainingData(TrainingData):
     def create_reaction_dataframe(self) -> Tuple[pd.DataFrame, Set[Compound]]:
         """Create the DataFrame of reactions for training."""
         tecr_df = self.read_tecrdb(
-            get_cached_filepath(
-                zenodo_doi=ZENODO_DOI_TRAINING_DATA, zenodo_fname="TECRDB.csv"
-            )
+            get_cached_filepath(TRAINING_DATA_TECR_SETTINGS)
         )
         tecr_df["weight"] = 1.0
 
         formation_df, non_decomposable_compounds = self.read_formations(
-            get_cached_filepath(
-                zenodo_doi=ZENODO_DOI_TRAINING_DATA,
-                zenodo_fname="formation_energies_transformed.csv",
-            )
+            get_cached_filepath(TRAINING_DATA_FORMATION_SETTINGS)
         )
         formation_df["weight"] = 1.0
 
         redox_df, more_non_decomposable_compounds = self.read_redox(
-            get_cached_filepath(
-                zenodo_doi=ZENODO_DOI_TRAINING_DATA, zenodo_fname="redox.csv"
-            )
+            get_cached_filepath(TRAINING_DATA_REDOX_SETTINGS)
         )
         redox_df["weight"] = 1.0
         non_decomposable_compounds.update(more_non_decomposable_compounds)
